@@ -25,12 +25,11 @@
 #include <KLocalizedString>
 
 #include "kubrick.h"
+#include "kubrick_version.h"
 
 static const char description [] =
     I18N_NOOP ("A game based on Rubik's Cube (TM)");
 
-static const char version [] = "1.1";
-
 int main(int argc, char **argv)
 {
     QApplication app(argc, argv);
@@ -38,10 +37,10 @@ int main(int argc, char **argv)
     KLocalizedString::setApplicationDomain("kubrick");
 
     KAboutData about (QStringLiteral("kubrick"), i18n ("Kubrick"),
-            QLatin1String(version), i18n (description),
+            KUBRICK_VERSION_STRING, i18n (description),
             KAboutLicense::GPL,
             i18n ("&copy; 2008 Ian Wadham"),
-            QStringLiteral("http://kde.org/applications/games/kubrick/") );
+            QStringLiteral("https://kde.org/applications/games/org.kde.kubrick") );
     about.addAuthor (i18n ("Ian Wadham"), i18n ("Author"),
                              QStringLiteral("iandw.au@gmail.com"));
     Kdelibs4ConfigMigrator migrate(QStringLiteral("kubrick"));
